@@ -33,6 +33,25 @@ const MAX_TRIGGERED_EVENT_COUNT: usize = 32;
 pub fn try_launching_debugger() {}
 
 pub fn main(config: ApplicationConfig) {
+    /*
+    if let Some(mut command) = crate::editor_utils::parse_process_command("pbpaste") {
+        command.stdin(std::process::Stdio::null());
+        command.stdout(std::process::Stdio::piped());
+        command.stderr(std::process::Stdio::null());
+        match command.output() {
+            Ok(output) => {
+                let stdout = String::from_utf8_lossy(&output.stdout);
+                eprintln!("stdout {}", &stdout);
+                let stderr = String::from_utf8_lossy(&output.stderr);
+                eprintln!("stderr {}", &stderr);
+            }
+            Err(error) => eprintln!("deu ruim 2: {}", error),
+        }
+    } else {
+        eprintln!("deu ruim 3");
+    }
+    */
+
     run(config, run_server, run_client);
 }
 
@@ -500,7 +519,7 @@ fn run_client(args: Args, mut connection: UnixStream) {
         kqueue.add(Event::Resize, 2, 0);
 
         let size = terminal.get_size();
-        let (_, bytes) = application.update(Some(size), &[Key::None], None, &[]);
+        let (_, bytes) = application.update(Some(size), &[Key::default()], None, &[]);
         if connection.write_all(bytes).is_err() {
             return;
         }
@@ -609,4 +628,3 @@ fn run_client(args: Args, mut connection: UnixStream) {
     drop(terminal);
     drop(application);
 }
-
