@@ -440,7 +440,7 @@ fn run_client(args: Args, mut connection: UnixStream) {
         resize_signal = Some(signal);
 
         let size = terminal.get_size();
-        let (_, bytes) = application.update(Some(size), &[Key::None], None, &[]);
+        let (_, bytes) = application.update(Some(size), &[Key::default()], None, &[]);
         if connection.write_all(bytes).is_err() {
             return;
         }
@@ -519,4 +519,3 @@ fn run_client(args: Args, mut connection: UnixStream) {
     drop(terminal);
     drop(application);
 }
-
